from atelier.invlib import setup_from_tasks

ns = setup_from_tasks(globals(),
                      "lino_amici",
                      languages="en de fr et".split(),
                      tolerate_sphinx_warnings=False,
                      blogref_url='https://luc.lino-framework.org',
                      revision_control_system='git',
                      locale_dir='lino_amici/lib/amici/locale',
                      cleanable_files=['docs/api/lino_amici.*'],
                      demo_projects=['lino_amici.projects.amici1'])



# Copyright 2017-2018 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)
"""
Lino Amici extension of :mod:`lino_xl.lib.contacts`.

"""

from lino_xl.lib.contacts import Plugin


class Plugin(Plugin):

    extends_models = ['Person', 'Company']

    # use_vcard_export = True



# -*- coding: UTF-8 -*-
# generated by lino.sphinxcontrib.help_text_builder
from __future__ import unicode_literals
from django.utils.translation import gettext_lazy as _

help_texts = {
    'lino_amici.lib.amici.migrate.Migrator':
    _("""The standard migrator for noi."""),
    'lino_amici.lib.amici.user_types.EndUser':
    _("""An end user is somebody who uses our database, but won't work
on it."""),
    'lino_amici.lib.amici.user_types.Collector':
    _("""A collector is somebody who collects data into the database."""),
    'lino_amici.lib.amici.user_types.ProjectManager':
    _("""A project manager additionally sees tickets, projects, courses,
meetings, calendar..."""),
    'lino_amici.lib.amici.user_types.SiteAdmin':
    _("""Can do everything."""),
}
